==> tamejs-0.1.5.tgz: package/test/cases/13.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    var ok = false ;
    
    exports [ "passThrough/compile test" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_5 = function (__tame_k) {
            function make_dict () {
                 for (var i = 0 ; i < 100 ; i ++) {
                    ;
                }
                var d = { cat :
                function  (n, cb) {
                    var __tame_this = this;
                    var __tame_fn_6 = function (__tame_k) {
                        var __tame_fn_7 = function (__tame_k) {
                            var __tame_k_implicit =  {};
                            var i = 0;
                            var __tame_fn_8 = function (__tame_k) {
                                var __tame_fn_9 = function (__tame_k) {
                                    i ++
                                    tame.callChain([__tame_fn_8, __tame_k]);
                                };
                                __tame_k_implicit.k_break = __tame_k;
                                __tame_k_implicit.k_continue = function() { __tame_fn_9(__tame_k); };
                                if (i < n) {
                                    var __tame_fn_10 = function (__tame_k) {
                                        var __tame_ev = new tame.Event (__tame_k);
                                        var __tame_fn_11 = function (__tame_k) {
                                            setTimeout ( __tame_ev.mkevent ( ) , 5 * Math .random ( ) ) ;
                                            tame.callChain([__tame_k]);
                                        };
                                        __tame_fn_11(tame.end);
                                        __tame_ev.trigger();
                                    };
                                    tame.callChain([__tame_fn_10, __tame_fn_9, __tame_k]);
                                } else {
                                    tame.callChain([__tame_k]);
                                }
                            };
                            tame.callChain([__tame_fn_8, __tame_k]);
                        };
                        var __tame_fn_12 = function (__tame_k) {
                            cb ( ) ;
                            tame.callChain([__tame_k]);
                        };
                        tame.callChain([__tame_fn_7, __tame_fn_12, __tame_k]);
                    };
                    tame.callChain([__tame_fn_6, __tame_k]);
                }
                , n : 10 } ;
                 for (var i = 0 ; i < 100 ; i ++) {
                    ;
                }
                return d;
            }
            ;
            
            var d = make_dict ( ) ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_ev = new tame.Event (__tame_k);
                    var __tame_fn_3 = function (__tame_k) {
                        d .cat ( d .n , __tame_ev.mkevent ( ) ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_3(tame.end);
                    __tame_ev.trigger();
                };
                var __tame_fn_4 = function (__tame_k) {
                    ok = true ;
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_5, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert .ok ( ok , "ok was set" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.2.1.tgz: package/test/cases/13.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    var ok = false ;
    
    exports [ "passThrough/compile test" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_5 = function (__tame_k) {
            function make_dict () {
                 for (var i = 0 ; i < 100 ; i ++) {
                    ;
                }
                var d = { cat :
                function  (n, cb) {
                    var __tame_this = this;
                    var __tame_fn_6 = function (__tame_k) {
                        var __tame_fn_7 = function (__tame_k) {
                            var __tame_k_implicit =  {};
                            var i = 0;
                            var __tame_fn_8 = function (__tame_k) {
                                var __tame_fn_9 = function (__tame_k) {
                                    i ++
                                    tame.callChain([__tame_fn_8, __tame_k]);
                                };
                                __tame_k_implicit.k_break = __tame_k;
                                __tame_k_implicit.k_continue = function() { __tame_fn_9(__tame_k); };
                                if (i < n) {
                                    var __tame_fn_10 = function (__tame_k) {
                                        var __tame_ev = new tame.Event (__tame_k);
                                        var __tame_fn_11 = function (__tame_k) {
                                            setTimeout (
                                            __tame_ev.mkevent ()
                                            , 5 * Math .random ( ) ) ;
                                            tame.callChain([__tame_k]);
                                        };
                                        __tame_fn_11(tame.end);
                                        __tame_ev.trigger();
                                    };
                                    tame.callChain([__tame_fn_10, __tame_fn_9, __tame_k]);
                                } else {
                                    tame.callChain([__tame_k]);
                                }
                            };
                            tame.callChain([__tame_fn_8, __tame_k]);
                        };
                        var __tame_fn_12 = function (__tame_k) {
                            cb ( ) ;
                            tame.callChain([__tame_k]);
                        };
                        tame.callChain([__tame_fn_7, __tame_fn_12, __tame_k]);
                    };
                    tame.callChain([__tame_fn_6, __tame_k]);
                }
                , n : 10 } ;
                 for (var i = 0 ; i < 100 ; i ++) {
                    ;
                }
                return d;
            }
            ;
            
            var d = make_dict ( ) ;
            var __tame_fn_1 = function (__tame_k) {
                var __tame_fn_2 = function (__tame_k) {
                    var __tame_ev = new tame.Event (__tame_k);
                    var __tame_fn_3 = function (__tame_k) {
                        d .cat ( d .n ,
                        __tame_ev.mkevent ()
                        ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_3(tame.end);
                    __tame_ev.trigger();
                };
                var __tame_fn_4 = function (__tame_k) {
                    ok = true ;
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
            };
            tame.callChain([__tame_fn_1, __tame_k]);
        };
        tame.callChain([__tame_fn_5, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert .ok ( ok , "ok was set" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
